@@ -76,17 +76,17 @@ class SafeEyes(Gtk.Application):
             ("settings", "s", _("show the settings dialog")),
             ("take-break", "t", _("Take a break now").lower()),
             # activate action
-            ("disable", "d", _("disable the currently running safeeyes instance")),
-            ("enable", "e", _("enable the currently running safeeyes instance")),
-            ("quit", "q", _("quit the running safeeyes instance and exit")),
+            ("disable", "d", _("disable the currently running Safe Eyes instance")),
+            ("enable", "e", _("enable the currently running Safe Eyes instance")),
+            ("quit", "q", _("quit the running Safe Eyes instance and exit")),
             # special handling
             (
                 "status",
                 None,
-                _("print the status of running safeeyes instance and exit"),
+                _("print the status of running Safe Eyes instance and exit"),
             ),
             # toggle
-            ("debug", None, _("start safeeyes in debug mode")),
+            ("debug", None, _("start Safe Eyes in debug mode")),
             # TODO: translate
             ("version", None, "show program's version number and exit"),
         ]
@@ -137,7 +137,7 @@ class SafeEyes(Gtk.Application):
         utility.cleanup_old_user_stylesheet()
 
         if options.contains("version"):
-            print(f"safeeyes {SAFE_EYES_VERSION}")
+            print(f"Safe Eyes {SAFE_EYES_VERSION}")
             return 0  # exit
 
         # needed for calling is_remote
@@ -347,7 +347,7 @@ class SafeEyes(Gtk.Application):
         dialog.show()
 
     def disable_plugin(self, plugin_id):
-        """Temporarily disable plugin, and restart SafeEyes."""
+        """Temporarily disable plugin, and restart Safe Eyes."""
         config = self.config.clone()
 
         for plugin in config.get("plugins"):
